https://github.com/netdata/netdata/pull/7877

From c65f57af0714558294c1ad1b9568077720fb282b Mon Sep 17 00:00:00 2001
From: Thiago Marques <thiagoftsm@gmail.com>
Date: Tue, 28 Jan 2020 13:59:20 +0000
Subject: [PATCH 1/2] missing_extern: Fix missing

Fix few externs that were missing in global variables
---
 daemon/common.h            | 2 +-
 health/health.h            | 2 +-
 libnetdata/health/health.h | 2 +-
 web/api/web_api_v1.h       | 2 +-
 4 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/daemon/common.h b/daemon/common.h
index 6ac3cb3c87..59dbc41a8d 100644
--- a/daemon/common.h
+++ b/daemon/common.h
@@ -84,6 +84,6 @@ extern char *netdata_configured_timezone;
 extern int netdata_zero_metrics_enabled;
 extern int netdata_anonymous_statistics_enabled;
 
-int netdata_ready;
+extern int netdata_ready;
 
 #endif /* NETDATA_COMMON_H */
diff --git a/health/health.h b/health/health.h
index 9da90d70c9..d77318fd78 100644
--- a/health/health.h
+++ b/health/health.h
@@ -52,7 +52,7 @@ extern unsigned int default_health_enabled;
 
 #define HEALTH_SILENCERS_MAX_FILE_LEN 10000
 
-char *silencers_filename;
+extern char *silencers_filename;
 
 extern void health_init(void);
 extern void *health_main(void *ptr);
diff --git a/libnetdata/health/health.h b/libnetdata/health/health.h
index a3dc0775fc..f7580edab2 100644
--- a/libnetdata/health/health.h
+++ b/libnetdata/health/health.h
@@ -44,7 +44,7 @@ typedef struct silencers {
     SILENCER *silencers;
 } SILENCERS;
 
-SILENCERS *silencers;
+extern SILENCERS *silencers;
 
 extern SILENCER *create_silencer(void);
 extern int health_silencers_json_read_callback(JSON_ENTRY *e);
diff --git a/web/api/web_api_v1.h b/web/api/web_api_v1.h
index 4fe3c8f6be..edeea98bed 100644
--- a/web/api/web_api_v1.h
+++ b/web/api/web_api_v1.h
@@ -29,6 +29,6 @@ extern void host_labels2json(RRDHOST *host, BUFFER *wb, size_t indentation);
 extern void web_client_api_v1_init(void);
 extern void web_client_api_v1_management_init(void);
 
-char *api_secret;
+extern char *api_secret;
 
 #endif //NETDATA_WEB_API_V1_H

From c0275ddaad62459a6da1eee0a0c76282a1391590 Mon Sep 17 00:00:00 2001
From: Thiago Marques <thiagoftsm@gmail.com>
Date: Tue, 28 Jan 2020 14:06:56 +0000
Subject: [PATCH 2/2] missing_extern: Variables

This commit declares the variables inside .c files
---
 daemon/common.c            | 2 +-
 health/health.c            | 1 +
 libnetdata/health/health.c | 2 ++
 web/api/web_api_v1.c       | 2 ++
 4 files changed, 6 insertions(+), 1 deletion(-)

diff --git a/daemon/common.c b/daemon/common.c
index e28f6cf000..67497a4e93 100644
--- a/daemon/common.c
+++ b/daemon/common.c
@@ -13,4 +13,4 @@ char *netdata_configured_varlib_dir          = VARLIB_DIR;
 char *netdata_configured_home_dir            = CACHE_DIR;
 char *netdata_configured_host_prefix         = NULL;
 char *netdata_configured_timezone            = NULL;
-
+int netdata_ready;
diff --git a/health/health.c b/health/health.c
index 1124cf9107..4a84ef7fca 100644
--- a/health/health.c
+++ b/health/health.c
@@ -9,6 +9,7 @@ struct health_cmdapi_thread_status {
 };
 
 unsigned int default_health_enabled = 1;
+char *silencers_filename;
 
 // ----------------------------------------------------------------------------
 // health initialization
diff --git a/libnetdata/health/health.c b/libnetdata/health/health.c
index e03538db3f..98d26d295f 100644
--- a/libnetdata/health/health.c
+++ b/libnetdata/health/health.c
@@ -1,5 +1,7 @@
 #include "health.h"
 
+SILENCERS *silencers;
+
 /**
  * Create Silencer
  *
diff --git a/web/api/web_api_v1.c b/web/api/web_api_v1.c
index aafcbc70be..4ac50524ad 100644
--- a/web/api/web_api_v1.c
+++ b/web/api/web_api_v1.c
@@ -2,6 +2,8 @@
 
 #include "web_api_v1.h"
 
+char *api_secret;
+
 static struct {
     const char *name;
     uint32_t hash;
